const MESSAGE_START: char = '<';
const MESSAGE_END: char = '>';

#[derive(Debug)]
pub struct MessageBuilder {
    message: String,
    complete: bool,
    started: bool,
}

impl MessageBuilder {
    pub fn check(&mut self, mut msg: String) -> Option<String> {
        // if message hasn't started, search for message start token
        if !self.started {
            let token_position = match msg.chars().position(|c| c == MESSAGE_START) {
                Some(position) => position,
                None => return None,
            };

            msg = msg.split_off(token_position + 1);
            self.started = true;
        }

        if !self.complete {
            match msg.chars().position(|c| c == MESSAGE_END) {
                Some(position) => {
                    let remaining_msg = msg.split_off(position);

                    self.message.push_str(&msg);
                    self.complete = true;

                    msg = remaining_msg;
                }
                None => {
                    self.message.push_str(&msg);
                    msg.clear();
                }
            };
        }

        if msg.is_empty() {
            None
        } else {
            Some(msg)
        }
    }

    pub fn is_complete(&self) -> bool {
        self.complete
    }

    pub fn message(&self) -> &str {
        &self.message
    }
}

impl Default for MessageBuilder {
    fn default() -> MessageBuilder {
        MessageBuilder {
            message: String::new(),
            complete: false,
            started: false,
        }
    }
}
